var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', './DatePicker.Props', './DatePickerDay', './DatePickerMonth', '../../TextField', '../../utilities/KeyCodes', '../../utilities/eventGroup/EventGroup', './DatePicker.scss'], function (require, exports, React, DatePicker_Props_1, DatePickerDay_1, DatePickerMonth_1, TextField_1, KeyCodes_1, EventGroup_1) {
    "use strict";
    var DatePicker = (function (_super) {
        __extends(DatePicker, _super);
        function DatePicker(props) {
            _super.call(this);
            var format = props.format, value = props.value;
            this.state = {
                selectedDate: new Date(),
                formattedDate: format && value ? format(value) : null,
                isDatePickerShown: false,
            };
            this._events = new EventGroup_1.EventGroup(this);
            this._preventFocusOpeningPicker = false;
            this._onSelectDate = this._onSelectDate.bind(this);
            this._onNavigateDate = this._onNavigateDate.bind(this);
            this._onGotoToday = this._onGotoToday.bind(this);
            this._onGotoTodayKeyDown = this._onGotoTodayKeyDown.bind(this);
            this._onTextFieldFocus = this._onTextFieldFocus.bind(this);
            this._onTextFieldKeyDown = this._onTextFieldKeyDown.bind(this);
            this._onTextFieldClick = this._onTextFieldClick.bind(this);
        }
        DatePicker.prototype.componentDidMount = function () {
            this._events.on(window, 'scroll', this._dismissDatePickerPopup);
            this._events.on(window, 'resize', this._dismissDatePickerPopup);
            this._events.on(window, 'click', this._onClickCapture, true);
            this._events.on(window, 'touchstart', this._onClickCapture, true);
        };
        DatePicker.prototype.componentWillUnmount = function () {
            this._events.dispose();
        };
        DatePicker.prototype.componentDidUpdate = function () {
            if (this._focusOnSelectedDateOnUpdate) {
                this.refs.dayPicker.focus();
                this._focusOnSelectedDateOnUpdate = false;
            }
        };
        DatePicker.prototype.render = function () {
            var rootClass = 'ms-DatePicker';
            var _a = this.props, firstDayOfWeek = _a.firstDayOfWeek, strings = _a.strings;
            var _b = this.state, isDatePickerShown = _b.isDatePickerShown, formattedDate = _b.formattedDate, selectedDate = _b.selectedDate, navigatedDate = _b.navigatedDate;
            return (React.createElement("div", {className: rootClass, ref: 'root'}, React.createElement("div", {ref: 'textFieldContainer'}, React.createElement(TextField_1.TextField, {onKeyDown: this._onTextFieldKeyDown, onFocus: this._onTextFieldFocus, onClick: this._onTextFieldClick, label: this.props.label, placeholder: this.props.placeholder, iconClass: 'ms-DatePicker-event ms-Icon ms-Icon--event', readOnly: true, value: formattedDate, ref: 'textField'})), isDatePickerShown && (React.createElement("div", {className: 'ms-DatePicker-picker ms-DatePicker-picker--opened ms-DatePicker-picker--focused'}, React.createElement("div", {className: 'ms-DatePicker-holder'}, React.createElement("div", {className: 'ms-DatePicker-frame'}, React.createElement("div", {className: 'ms-DatePicker-wrap'}, React.createElement(DatePickerDay_1.DatePickerDay, {selectedDate: selectedDate, navigatedDate: navigatedDate, onSelectDate: this._onSelectDate, onNavigateDate: this._onNavigateDate, firstDayOfWeek: firstDayOfWeek, strings: strings, ref: 'dayPicker'}), React.createElement(DatePickerMonth_1.DatePickerMonth, {navigatedDate: navigatedDate, strings: strings, onNavigateDate: this._onNavigateDate}), React.createElement("span", {className: 'ms-DatePicker-goToday js-goToday', onClick: this._onGotoToday, onKeyDown: this._onGotoTodayKeyDown, tabIndex: 0}, strings.goToToday))))))));
        };
        DatePicker.prototype._restoreFocusToTextField = function () {
            this._preventFocusOpeningPicker = true;
            this.refs.textField.focus();
        };
        DatePicker.prototype._navigateDay = function (date) {
            this.setState({
                navigatedDate: date
            });
        };
        DatePicker.prototype._onNavigateDate = function (date, focusOnNavigatedDay) {
            this._focusOnSelectedDateOnUpdate = this._focusOnSelectedDateOnUpdate || focusOnNavigatedDay;
            this._navigateDay(date);
        };
        DatePicker.prototype._onSelectDate = function (date) {
            var _a = this.props, format = _a.format, onSelectDate = _a.onSelectDate;
            this.setState({
                selectedDate: date,
                isDatePickerShown: false,
                formattedDate: format && date ? format(date) : null,
            });
            this._restoreFocusToTextField();
            if (onSelectDate) {
                onSelectDate(date);
            }
        };
        ;
        DatePicker.prototype._onGotoToday = function () {
            this._focusOnSelectedDateOnUpdate = true;
            this._navigateDay(new Date());
        };
        ;
        DatePicker.prototype._onGotoTodayKeyDown = function (ev) {
            if (ev.which === KeyCodes_1.KeyCodes.enter) {
                this._onGotoToday();
            }
        };
        ;
        DatePicker.prototype._onTextFieldFocus = function (evt) {
            if (!this._preventFocusOpeningPicker) {
                this._showDatePickerPopup();
            }
            this._preventFocusOpeningPicker = false;
        };
        ;
        DatePicker.prototype._onTextFieldKeyDown = function (evt) {
            if (evt.which === KeyCodes_1.KeyCodes.enter) {
                this._showDatePickerPopup();
            }
            else if (evt.which === KeyCodes_1.KeyCodes.escape) {
                this._restoreFocusToTextField();
                this._dismissDatePickerPopup();
            }
        };
        ;
        DatePicker.prototype._onClickCapture = function (ev) {
            if (!this.refs.root.contains(ev.target)) {
                this._dismissDatePickerPopup();
            }
        };
        DatePicker.prototype._onTextFieldClick = function (ev) {
            if (!this.state.isDatePickerShown) {
                this._showDatePickerPopup();
            }
        };
        DatePicker.prototype._showDatePickerPopup = function () {
            if (!this.state.isDatePickerShown) {
                this._focusOnSelectedDateOnUpdate = true;
                this.setState({
                    isDatePickerShown: true,
                    navigatedDate: this.state.selectedDate
                });
            }
        };
        DatePicker.prototype._dismissDatePickerPopup = function () {
            if (this.state.isDatePickerShown) {
                this.setState({
                    isDatePickerShown: false
                });
            }
        };
        DatePicker.defaultProps = {
            format: function (date) {
                if (date) {
                    return date.toDateString();
                }
                return null;
            },
            firstDayOfWeek: DatePicker_Props_1.DayOfWeek.Sunday,
            strings: null
        };
        return DatePicker;
    }(React.Component));
    exports.DatePicker = DatePicker;
});
