var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
define(["require", "exports", 'react', '../../utilities/css', '../../utilities/eventGroup/EventGroup', './Image.Props', './Image.scss'], function (require, exports, React, css_1, EventGroup_1, Image_Props_1) {
    "use strict";
    (function (CoverStyle) {
        CoverStyle[CoverStyle["landscape"] = 0] = "landscape";
        CoverStyle[CoverStyle["portrait"] = 1] = "portrait";
    })(exports.CoverStyle || (exports.CoverStyle = {}));
    var CoverStyle = exports.CoverStyle;
    exports.CoverStyleMap = (_a = {},
        _a[CoverStyle.landscape] = 'ms-Image--landscape',
        _a[CoverStyle.portrait] = 'ms-Image--portrait',
        _a
    );
    exports.ImageFitMap = (_b = {},
        _b[Image_Props_1.ImageFit.center] = 'ms-Image--center',
        _b[Image_Props_1.ImageFit.cover] = 'ms-Image--cover',
        _b[Image_Props_1.ImageFit.none] = 'ms-Image--none',
        _b[Image_Props_1.ImageFit.scale] = 'ms-Image--scale',
        _b
    );
    (function (ImageLoadState) {
        ImageLoadState[ImageLoadState["notLoaded"] = 0] = "notLoaded";
        ImageLoadState[ImageLoadState["loaded"] = 1] = "loaded";
        ImageLoadState[ImageLoadState["error"] = 2] = "error";
        ImageLoadState[ImageLoadState["errorLoaded"] = 3] = "errorLoaded";
    })(exports.ImageLoadState || (exports.ImageLoadState = {}));
    var ImageLoadState = exports.ImageLoadState;
    var Image = (function (_super) {
        __extends(Image, _super);
        function Image(props) {
            _super.call(this, props);
            this.state = {
                loadState: ImageLoadState.notLoaded
            };
            this._events = new EventGroup_1.EventGroup(this);
        }
        Image.prototype.componentDidMount = function () {
            var image = this.refs.image;
            if (!this._evaluateImage()) {
                this._events.on(image, 'load', this._evaluateImage);
                this._events.on(image, 'error', this._setError);
            }
        };
        Image.prototype.componentWillUnmount = function () {
            this._events.dispose();
        };
        Image.prototype.render = function () {
            var _a = this.props, src = _a.src, alt = _a.alt, width = _a.width, height = _a.height, shouldFadeIn = _a.shouldFadeIn, className = _a.className, imageFit = _a.imageFit, errorSrc = _a.errorSrc;
            var loadState = this.state.loadState;
            var coverStyle = this._coverStyle;
            var loaded = loadState === ImageLoadState.loaded || loadState === ImageLoadState.errorLoaded;
            var srcToDisplay = (loadState === ImageLoadState.error || loadState === ImageLoadState.errorLoaded) ? errorSrc : src;
            // If image dimensions aren't specified, the natural size of the image is used.
            return (React.createElement("div", {className: css_1.css('ms-Image-container', className), style: { width: width, height: height }}, React.createElement("img", {className: css_1.css('ms-Image', (coverStyle !== undefined) && exports.CoverStyleMap[coverStyle], (imageFit !== undefined) && exports.ImageFitMap[imageFit], {
                'is-fadeIn': shouldFadeIn,
                'is-notLoaded': !loaded,
                'is-loaded': loaded,
                'ms-u-fadeIn400': loaded && shouldFadeIn,
                'is-error': loadState === ImageLoadState.error,
                'ms-Image--scale': (imageFit === undefined && !!width && !!height),
            }), ref: 'image', src: srcToDisplay, alt: alt})));
        };
        Image.prototype._evaluateImage = function () {
            var _a = this.props, src = _a.src, width = _a.width, height = _a.height;
            var loadState = this.state.loadState;
            var image = this.refs.image;
            var isLoaded = (src && image.naturalWidth > 0 && image.naturalHeight > 0);
            var desiredRatio = width / height;
            var naturalRatio = image.naturalWidth / image.naturalHeight;
            if (naturalRatio > desiredRatio) {
                this._coverStyle = CoverStyle.landscape;
            }
            else {
                this._coverStyle = CoverStyle.portrait;
            }
            if (isLoaded && loadState !== ImageLoadState.loaded && loadState !== ImageLoadState.errorLoaded) {
                this._events.off();
                this.setState({
                    loadState: loadState === ImageLoadState.error ? ImageLoadState.errorLoaded : ImageLoadState.loaded
                });
            }
            return isLoaded;
        };
        Image.prototype._setError = function () {
            if (this.state.loadState !== ImageLoadState.error && this.state.loadState !== ImageLoadState.errorLoaded) {
                if (this.props.onError) {
                    this.props.onError(this.props.src);
                }
                this.setState({
                    loadState: ImageLoadState.error
                });
            }
        };
        Image.defaultProps = {
            shouldFadeIn: true
        };
        return Image;
    }(React.Component));
    exports.Image = Image;
    var _a, _b;
});
