import * as React from 'react';
import { IPivotProps } from './Pivot.Props';
import './Pivot.scss';
/**
 *  Usage:
 *
 *   <Pivot>
 *     <PivotItem linkText="Foo">
 *       <Label>Pivot #1</Label>
 *     </PivotItem>
 *     <PivotItem linkText="Bar">
 *       <Label>Pivot #2</Label>
 *     </PivotItem>
 *     <PivotItem linkText="Bas">
 *     <Label>Pivot #3</Label>
 *     </PivotItem>
 *   </Pivot>
 */
export interface IPivotState {
    selectedIndex: number;
}
export declare class Pivot extends React.Component<IPivotProps, IPivotState> {
    constructor(props?: IPivotProps);
    componentWillReceiveProps(newProps: IPivotProps): void;
    render(): JSX.Element;
    /**
     * Renders the set of links to route between pivots
     */
    private _renderPivotLinks();
    /**
     * Renders a pivot link
     */
    private _renderLink(link, index, links);
    /**
     * Renders the current Pivot Item
     */
    private _renderPivotItem();
    /**
     * Gets the set of PivotLinks as arrary of IPivotLink
     * The set of Links is determined by child components of type PivotItem
     */
    private getPivotLinks();
    /**
     * Handles the onClick event on PivotLinks
     */
    private _onLinkClick(index, ev);
    /**
     * Handle the onKeyPress eventon the PivotLinks
     */
    private _onKeyPress(index, ev);
    /**
     * Updates the state with the new selected index
     */
    private _updateSelectedItem(index, ev?);
    /**
     * returns new state state based on the provided Props
     */
    private _getStateFromProps(newProps);
}
