"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require('react');
var Label_1 = require('../../Label');
var css_1 = require('../../utilities/css');
var Async_1 = require('../../utilities/Async/Async');
require('./TextField.scss');
var _instance = 0;
var TextField = (function (_super) {
    __extends(TextField, _super);
    function TextField(props) {
        _super.call(this, props);
        this._id = "TextField-" + _instance++;
        this._descriptionId = "TextFieldDescription-" + _instance++;
        this._async = new Async_1.Async(this);
        this.state = {
            value: props.value,
            errorMessage: ''
        };
        this._onInputChange = this._onInputChange.bind(this);
        this._delayedValidate = this._async.debounce(this._validate, this.props.deferredValidationTime);
        this._lastValidation = 0;
        this._latestValidateValue = '';
        this._willMountTriggerValidation = false;
    }
    TextField.prototype.componentWillMount = function () {
        this._willMountTriggerValidation = true;
        this._validate(this.state.value);
    };
    TextField.prototype.componentDidMount = function () {
        this._isMounted = true;
    };
    TextField.prototype.componentWillReceiveProps = function (newProps) {
        if (newProps.value !== this.props.value
            && newProps.value !== this.state.value) {
            this.setState({
                value: newProps.value
            });
            var onBeforeChange = this.props.onBeforeChange;
            onBeforeChange(newProps.value);
            this._delayedValidate(newProps.value);
        }
    };
    TextField.prototype.componentWillUnmount = function () {
        this._async.dispose();
        this._isMounted = false;
    };
    TextField.prototype.render = function () {
        var _a = this.props, disabled = _a.disabled, required = _a.required, multiline = _a.multiline, underlined = _a.underlined, label = _a.label, description = _a.description, iconClass = _a.iconClass, className = _a.className;
        var errorMessage = this._errorMessage;
        var textFieldClassName = css_1.css('ms-TextField', className, {
            'is-required': required,
            'is-disabled': disabled,
            'ms-TextField--multiline': multiline,
            'ms-TextField--underlined': underlined
        });
        return (React.createElement("div", {className: textFieldClassName}, label && React.createElement(Label_1.Label, {htmlFor: this._id}, label), iconClass && React.createElement("i", {className: iconClass}), multiline ? this._renderTextArea() : this._renderInput(), errorMessage && React.createElement("p", {className: 'ms-TextField-errorMessage ms-u-slideDownIn20'}, errorMessage), errorMessage && React.createElement("div", {"aria-live": 'assertive', className: 'ms-u-screenReaderOnly', "data-automation-id": 'error-message'}, errorMessage), description && React.createElement("span", {className: 'ms-TextField-description'}, description), this.props.ariaLabel && React.createElement("span", {id: this._descriptionId, className: 'ms-TextField-hidden'}, this.props.ariaLabel)));
    };
    TextField.prototype.focus = function () {
        if (this.refs.field) {
            this.refs.field.focus();
        }
    };
    Object.defineProperty(TextField.prototype, "_fieldClassName", {
        get: function () {
            var errorMessage = this._errorMessage;
            return css_1.css('ms-TextField-field', {
                'ms-TextField-invalid': !!errorMessage
            });
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(TextField.prototype, "_errorMessage", {
        get: function () {
            var errorMessage = this.state.errorMessage;
            if (!errorMessage) {
                errorMessage = this.props.errorMessage;
            }
            return errorMessage;
        },
        enumerable: true,
        configurable: true
    });
    TextField.prototype._renderTextArea = function () {
        return (React.createElement("textarea", React.__spread({}, this.props, {id: this._id, ref: 'field', value: this.state.value, onChange: this._onInputChange, className: this._fieldClassName})));
    };
    TextField.prototype._renderInput = function () {
        return (React.createElement("input", React.__spread({}, this.props, {id: this._id, type: 'text', ref: 'field', value: this.state.value, onChange: this._onInputChange, className: this._fieldClassName, "aria-describedby": this._descriptionId})));
    };
    TextField.prototype._onInputChange = function (event) {
        var element = event.target;
        var value = element.value;
        this.setState({
            value: value,
            errorMessage: ''
        });
        this._willMountTriggerValidation = false;
        this._delayedValidate(value);
        var onBeforeChange = this.props.onBeforeChange;
        onBeforeChange(value);
    };
    TextField.prototype._validate = function (value) {
        var _this = this;
        // In case of _validate called multi-times during executing validate logic with promise return.
        if (this._latestValidateValue === value) {
            return;
        }
        this._latestValidateValue = value;
        var onGetErrorMessage = this.props.onGetErrorMessage;
        var result = onGetErrorMessage(value || '');
        if (result !== undefined) {
            if (typeof result === 'string') {
                this.setState({
                    errorMessage: result
                });
                this._notifyAfterValidate(value, result);
            }
            else {
                var currentValidation_1 = ++this._lastValidation;
                result.then(function (errorMessage) {
                    if (_this._isMounted && currentValidation_1 === _this._lastValidation) {
                        _this.setState({ errorMessage: errorMessage });
                    }
                    _this._notifyAfterValidate(value, errorMessage);
                });
            }
        }
        else {
            this._notifyAfterValidate(value, '');
        }
    };
    TextField.prototype._notifyAfterValidate = function (value, errorMessage) {
        if (!this._willMountTriggerValidation && value === this.state.value) {
            var onNotifyValidationResult = this.props.onNotifyValidationResult;
            onNotifyValidationResult(errorMessage, value);
            if (!errorMessage) {
                var onChanged = this.props.onChanged;
                onChanged(value);
            }
        }
        else {
            this._willMountTriggerValidation = false;
        }
    };
    TextField.defaultProps = {
        multiline: false,
        underlined: false,
        onChanged: function () { },
        onBeforeChange: function () { },
        onNotifyValidationResult: function () { },
        onGetErrorMessage: function () { return undefined; },
        deferredValidationTime: 200,
        errorMessage: ''
    };
    return TextField;
}(React.Component));
exports.TextField = TextField;

//# sourceMappingURL=TextField.js.map
