"use strict";
var __extends = (this && this.__extends) || function (d, b) {
    for (var p in b) if (b.hasOwnProperty(p)) d[p] = b[p];
    function __() { this.constructor = d; }
    d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
};
var React = require('react');
var index_1 = require('../../../../index');
var interfaces_1 = require('../../../../utilities/selection/interfaces');
var data_1 = require('../../../utilities/data');
require('./DetailsList.Basic.Example.scss');
var DEFAULT_ITEM_LIMIT = 5;
var PAGING_SIZE = 10;
var PAGING_DELAY = 5000;
var ITEMS_COUNT = 5000;
var _items;
var DetailsListBasicExample = (function (_super) {
    __extends(DetailsListBasicExample, _super);
    function DetailsListBasicExample() {
        _super.call(this);
        if (!_items) {
            _items = data_1.createListItems(ITEMS_COUNT);
        }
        this._onToggleResizing = this._onToggleResizing.bind(this);
        this._onToggleLazyLoad = this._onToggleLazyLoad.bind(this);
        this._onLayoutChanged = this._onLayoutChanged.bind(this);
        this._onConstrainModeChanged = this._onConstrainModeChanged.bind(this);
        this._onSelectionChanged = this._onSelectionChanged.bind(this);
        this._onColumnClick = this._onColumnClick.bind(this);
        this._onContextualMenuDismissed = this._onContextualMenuDismissed.bind(this);
        this._onItemLimitChanged = this._onItemLimitChanged.bind(this);
        this.state = {
            items: _items,
            groups: null,
            groupItemLimit: DEFAULT_ITEM_LIMIT,
            layoutMode: index_1.DetailsListLayoutMode.justified,
            constrainMode: index_1.ConstrainMode.horizontalConstrained,
            selectionMode: interfaces_1.SelectionMode.multiple,
            canResizeColumns: true,
            columns: this._buildColumns(_items, true, this._onColumnClick, ''),
            contextualMenuProps: null,
            sortedColumnKey: 'name',
            isSortedDescending: false,
            isLazyLoaded: false,
            isHeaderVisible: true
        };
    }
    DetailsListBasicExample.prototype.render = function () {
        var _this = this;
        var _a = this.state, items = _a.items, groups = _a.groups, groupItemLimit = _a.groupItemLimit, layoutMode = _a.layoutMode, constrainMode = _a.constrainMode, selectionMode = _a.selectionMode, columns = _a.columns, contextualMenuProps = _a.contextualMenuProps, isHeaderVisible = _a.isHeaderVisible;
        var isGrouped = groups && groups.length > 0;
        var groupProps = {
            getGroupItemLimit: function (group) {
                if (group) {
                    return group.isShowingAll ? group.count : Math.min(group.count, groupItemLimit);
                }
                else {
                    return items.length;
                }
            },
            footerProps: {
                showAllLinkText: 'Show all'
            }
        };
        return (React.createElement("div", {className: 'ms-DetailsListBasicExample'}, React.createElement(index_1.CommandBar, {items: this._getCommandItems()}), (isGrouped) ?
            React.createElement(index_1.TextField, {label: 'Group Item Limit', onChanged: this._onItemLimitChanged}) :
            (null), React.createElement(index_1.DetailsList, {setKey: 'items', items: items, groups: groups, columns: columns, layoutMode: layoutMode, isHeaderVisible: isHeaderVisible, selectionMode: selectionMode, constrainMode: constrainMode, groupProps: groupProps, onItemInvoked: this._onItemInvoked, ariaLabelForListHeader: 'Column headers. Use menus to perform column operations like sort and filter', ariaLabelForSelectAllCheckbox: 'Toggle selection for all items', onRenderMissingItem: function (index) {
            _this._onDataMiss(index);
            return null;
        }}), contextualMenuProps && (React.createElement(index_1.ContextualMenu, React.__spread({}, contextualMenuProps)))));
    };
    DetailsListBasicExample.prototype._onDataMiss = function (index) {
        var _this = this;
        index = Math.floor(index / PAGING_SIZE) * PAGING_SIZE;
        if (!this._isFetchingItems) {
            this._isFetchingItems = true;
            setTimeout(function () {
                _this._isFetchingItems = false;
                var itemsCopy = [].concat(_this.state.items);
                itemsCopy.splice.apply(itemsCopy, [index, PAGING_SIZE].concat(_items.slice(index, index + PAGING_SIZE)));
                _this.setState({
                    items: itemsCopy
                });
            }, PAGING_DELAY);
        }
    };
    DetailsListBasicExample.prototype._onToggleLazyLoad = function () {
        var isLazyLoaded = this.state.isLazyLoaded;
        isLazyLoaded = !isLazyLoaded;
        this.setState({
            isLazyLoaded: isLazyLoaded,
            items: isLazyLoaded ? _items.slice(0, PAGING_SIZE).concat(new Array(ITEMS_COUNT - PAGING_SIZE)) : _items
        });
    };
    DetailsListBasicExample.prototype._onToggleResizing = function () {
        var _a = this.state, items = _a.items, canResizeColumns = _a.canResizeColumns, sortedColumnKey = _a.sortedColumnKey, isSortedDescending = _a.isSortedDescending;
        canResizeColumns = !canResizeColumns;
        this.setState({
            canResizeColumns: canResizeColumns,
            columns: this._buildColumns(items, canResizeColumns, this._onColumnClick, sortedColumnKey, isSortedDescending)
        });
    };
    DetailsListBasicExample.prototype._onLayoutChanged = function (menuItem) {
        this.setState({
            layoutMode: menuItem.data
        });
    };
    DetailsListBasicExample.prototype._onConstrainModeChanged = function (menuItem) {
        this.setState({
            constrainMode: menuItem.data
        });
    };
    DetailsListBasicExample.prototype._onSelectionChanged = function (menuItem) {
        this.setState({
            selectionMode: menuItem.data
        });
    };
    DetailsListBasicExample.prototype._onItemLimitChanged = function (value) {
        var newValue = parseInt(value, 10);
        if (isNaN(newValue)) {
            newValue = DEFAULT_ITEM_LIMIT;
        }
        this.setState({
            groupItemLimit: newValue
        });
    };
    DetailsListBasicExample.prototype._getCommandItems = function () {
        var _this = this;
        var _a = this.state, layoutMode = _a.layoutMode, constrainMode = _a.constrainMode, selectionMode = _a.selectionMode, canResizeColumns = _a.canResizeColumns, isLazyLoaded = _a.isLazyLoaded, isHeaderVisible = _a.isHeaderVisible;
        return [
            {
                key: 'configure',
                name: 'Configure',
                icon: 'gear',
                items: [
                    {
                        key: 'resizing',
                        name: 'Allow column resizing',
                        canCheck: true,
                        isChecked: canResizeColumns,
                        onClick: this._onToggleResizing
                    },
                    {
                        key: 'headerVisible',
                        name: 'Is header visible',
                        canCheck: true,
                        isChecked: isHeaderVisible,
                        onClick: function () { return _this.setState({ isHeaderVisible: !isHeaderVisible }); }
                    },
                    {
                        key: 'lazyload',
                        name: 'Simulate async loading',
                        canCheck: true,
                        isChecked: isLazyLoaded,
                        onClick: this._onToggleLazyLoad
                    },
                    {
                        key: 'dash',
                        name: '-'
                    },
                    {
                        key: 'layoutMode',
                        name: 'Layout mode',
                        items: [
                            {
                                key: index_1.DetailsListLayoutMode[index_1.DetailsListLayoutMode.fixedColumns],
                                name: 'Fixed columns',
                                canCheck: true,
                                isChecked: layoutMode === index_1.DetailsListLayoutMode.fixedColumns,
                                onClick: this._onLayoutChanged,
                                data: index_1.DetailsListLayoutMode.fixedColumns
                            },
                            {
                                key: index_1.DetailsListLayoutMode[index_1.DetailsListLayoutMode.justified],
                                name: 'Justified columns',
                                canCheck: true,
                                isChecked: layoutMode === index_1.DetailsListLayoutMode.justified,
                                onClick: this._onLayoutChanged,
                                data: index_1.DetailsListLayoutMode.justified
                            }
                        ]
                    },
                    {
                        key: 'selectionMode',
                        name: 'Selection mode',
                        items: [
                            {
                                key: interfaces_1.SelectionMode[interfaces_1.SelectionMode.none],
                                name: 'None',
                                canCheck: true,
                                isChecked: selectionMode === interfaces_1.SelectionMode.none,
                                onClick: this._onSelectionChanged,
                                data: interfaces_1.SelectionMode.none
                            },
                            {
                                key: interfaces_1.SelectionMode[interfaces_1.SelectionMode.single],
                                name: 'Single select',
                                canCheck: true,
                                isChecked: selectionMode === interfaces_1.SelectionMode.single,
                                onClick: this._onSelectionChanged,
                                data: interfaces_1.SelectionMode.single
                            },
                            {
                                key: interfaces_1.SelectionMode[interfaces_1.SelectionMode.multiple],
                                name: 'Multi select',
                                canCheck: true,
                                isChecked: selectionMode === interfaces_1.SelectionMode.multiple,
                                onClick: this._onSelectionChanged,
                                data: interfaces_1.SelectionMode.multiple
                            },
                        ]
                    },
                    {
                        key: 'constrainMode',
                        name: 'Constrain mode',
                        items: [
                            {
                                key: index_1.ConstrainMode[index_1.ConstrainMode.unconstrained],
                                name: 'Unconstrained',
                                canCheck: true,
                                isChecked: constrainMode === index_1.ConstrainMode.unconstrained,
                                onClick: this._onConstrainModeChanged,
                                data: index_1.ConstrainMode.unconstrained
                            },
                            {
                                key: index_1.ConstrainMode[index_1.ConstrainMode.horizontalConstrained],
                                name: 'Horizontal constrained',
                                canCheck: true,
                                isChecked: constrainMode === index_1.ConstrainMode.horizontalConstrained,
                                onClick: this._onConstrainModeChanged,
                                data: index_1.ConstrainMode.horizontalConstrained
                            }
                        ]
                    }
                ]
            }
        ];
    };
    DetailsListBasicExample.prototype._getContextualMenuProps = function (column, ev) {
        var _this = this;
        var items = [
            {
                key: 'aToZ',
                name: 'A to Z',
                icon: 'arrowUp2',
                canCheck: true,
                isChecked: column.isSorted && !column.isSortedDescending,
                onClick: function () { return _this._onSortColumn(column.key, false); }
            },
            {
                key: 'zToA',
                name: 'Z to A',
                icon: 'arrowDown2',
                canCheck: true,
                isChecked: column.isSorted && column.isSortedDescending,
                onClick: function () { return _this._onSortColumn(column.key, true); }
            }
        ];
        if (data_1.isGroupable(column.key)) {
            items.push({
                key: 'groupBy',
                name: 'Group By ' + column.name,
                icon: 'listGroup2',
                canCheck: true,
                isChecked: column.isGrouped,
                onClick: function () { return _this._onGroupByColumn(column); }
            });
        }
        return {
            items: items,
            targetElement: ev.currentTarget,
            directionalHint: index_1.DirectionalHint.bottomLeftEdge,
            gapSpace: 10,
            isBeakVisible: true,
            onDismiss: this._onContextualMenuDismissed
        };
    };
    DetailsListBasicExample.prototype._onItemInvoked = function (item, index) {
        console.log('Item invoked', item, index);
    };
    DetailsListBasicExample.prototype._onColumnClick = function (column, ev) {
        this.setState({
            contextualMenuProps: this._getContextualMenuProps(column, ev)
        });
    };
    DetailsListBasicExample.prototype._onContextualMenuDismissed = function () {
        this.setState({
            contextualMenuProps: null
        });
    };
    DetailsListBasicExample.prototype._onSortColumn = function (key, isSortedDescending) {
        var sortedItems = _items.slice(0).sort(function (a, b) { return (isSortedDescending ? a[key] < b[key] : a[key] > b[key]) ? 1 : -1; });
        this.setState({
            items: sortedItems,
            groups: null,
            columns: this._buildColumns(sortedItems, true, this._onColumnClick, key, isSortedDescending),
            isSortedDescending: isSortedDescending,
            sortedColumnKey: key
        });
    };
    DetailsListBasicExample.prototype._onGroupByColumn = function (column) {
        var key = column.key, isGrouped = column.isGrouped;
        var _a = this.state, sortedColumnKey = _a.sortedColumnKey, isSortedDescending = _a.isSortedDescending, groups = _a.groups, items = _a.items, columns = _a.columns;
        if (isGrouped) {
            this._onSortColumn(sortedColumnKey, isSortedDescending);
        }
        else {
            var groupedItems = [];
            var newGroups = null;
            if (groups) {
                newGroups = groups;
                groupedItems = this._groupByKey(newGroups, items, key);
            }
            else {
                groupedItems = this._groupItems(items, key);
                newGroups = this._getGroups(groupedItems, key);
            }
            var newColumns = columns;
            newColumns.filter(function (matchColumn) { return matchColumn.key === key; }).forEach(function (groupedColumn) {
                groupedColumn.isGrouped = true;
            });
            this.setState({
                items: groupedItems,
                columns: newColumns,
                groups: newGroups
            });
        }
    };
    DetailsListBasicExample.prototype._groupByKey = function (groups, items, key) {
        var _this = this;
        var groupedItems = [];
        if (groups) {
            groups.forEach(function (group) {
                if (group.children && group.children.length > 0) {
                    var childGroupedItems = _this._groupByKey(group.children, items, key);
                    groupedItems = groupedItems.concat(childGroupedItems);
                }
                else {
                    var itemsInGroup = items.slice(group.startIndex, group.startIndex + group.count);
                    var nextLevelGroupedItems = _this._groupItems(itemsInGroup, key);
                    groupedItems = groupedItems.concat(nextLevelGroupedItems);
                    group.children = _this._getGroups(nextLevelGroupedItems, key, group);
                }
            });
        }
        return groupedItems;
    };
    DetailsListBasicExample.prototype._groupItems = function (items, columnKey) {
        return items.slice(0).sort(function (a, b) { return ((a[columnKey] < b[columnKey]) ? -1 : 1); });
    };
    DetailsListBasicExample.prototype._getGroups = function (groupedItems, key, parentGroup) {
        var _this = this;
        var separator = '-';
        var groups = groupedItems.reduce(function (current, item, index) {
            var currentGroup = current[current.length - 1];
            if (!currentGroup || (_this._getLeafGroupKey(currentGroup.key, separator) !== item[key])) {
                current.push({
                    key: (parentGroup ? parentGroup.key + separator : '') + item[key],
                    name: key + ': ' + item[key],
                    startIndex: parentGroup ? parentGroup.startIndex + index : index,
                    count: 1,
                    level: parentGroup ? parentGroup.level + 1 : 0
                });
            }
            else {
                currentGroup.count++;
            }
            return current;
        }, []);
        return groups;
    };
    DetailsListBasicExample.prototype._getLeafGroupKey = function (key, separator) {
        var leafKey = key;
        if (key.indexOf(separator) !== -1) {
            var arrKeys = key.split(separator);
            leafKey = arrKeys[arrKeys.length - 1];
        }
        return leafKey;
    };
    DetailsListBasicExample.prototype._buildColumns = function (items, canResizeColumns, onColumnClick, sortedColumnKey, isSortedDescending, groupedColumnKey) {
        var columns = index_1.buildColumns(items, canResizeColumns, onColumnClick, sortedColumnKey, isSortedDescending, groupedColumnKey);
        columns.forEach(function (column) {
            if (column.key === 'description') {
                column.isMultiline = true;
                column.minWidth = 200;
            }
            else if (column.key === 'name') {
                column.onRender = function (item) { return (React.createElement(index_1.Link, null, item.name)); };
            }
            else if (column.key === 'key') {
                column.columnActionsMode = index_1.ColumnActionsMode.disabled;
                column.onRender = function (item) { return (React.createElement(index_1.Link, {href: '#'}, item.key)); };
                column.minWidth = 90;
                column.maxWidth = 90;
            }
        });
        return columns;
    };
    return DetailsListBasicExample;
}(React.Component));
exports.DetailsListBasicExample = DetailsListBasicExample;

//# sourceMappingURL=DetailsList.Basic.Example.js.map
